@@ -4,12 +4,12 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000040-000001"; }
+sub IDENTIFICATION { return "000001-000040-000002"; }
 
 sub preference { return 1500; }
 
@@ -17,7 +17,7 @@ sub handle_action {
 	my ($obj,%action) = @_;
 
 	if ($action{action} eq 'COMMAND') {
-		if ($action{cmd} =~ /^\\csvin(?:\[(.*)\])?\((.*?)\)\s+(.*)$/i) {
+		if ($action{cmd} =~ /^\\csvin(?:\[(.*)\])?\s*\((.*?)\)\s+(.*)$/i) {
 			$action{action} = 'CSV_IN';
 			$action{file} = $2;
 			$action{sql} = $3;
@@ -53,3 +53,24 @@ sub cmdhelp {
 	];
 }
 
+sub restart_complete {
+	my ($obj,$text,$line,$start) = @_;
+	my %action = (action => 'LINE_COMPLETE', text => $text, line => $line,
+		start => $start);
+	do {
+		%action = $obj->{-core}->handle_action(%action);
+	} until ($action{processed});
+	return @{$action{list}} if ref $action{list} eq 'ARRAY';
+	return $action{list} if $action{list};
+	return ();
+}
+
+sub cmdcomplete {
+	my ($obj,$text,$line,$start) = @_;
+	return () unless $obj->{-dbi}->current;
+	return $obj->restart_complete($text,$1,$start-(length($line)-length($1))) if $line =~ /^\s*\\csvin(?:\[.*?\])?\s*\(.+?\)\s+(.*)$/i;
+	return $obj->{-interface}->filenames_complete($text,$line,$start) if $line =~ /^\s*\\csvin(\[.*?\])?\s*\(\S*$/i;
+	return ('\csvin') if $line =~ /^\s*$/i;
+	return ('csvin(') if $line =~ /^\s*\\[A-Z]*$/i;
+	return ();
+}
