@@ -4,12 +4,12 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000003-000002"; }
+sub IDENTIFICATION { return "000001-000003-000003"; }
 
 sub preference { return 1000; }
 
@@ -31,3 +31,8 @@ sub cmdhelp {
 	];
 }
 
+sub cmdcomplete {
+	my ($obj,$text,$line,$start) = @_;
+	return qw/QUIT EXIT LOGOUT/ if $line =~ /^\s*[A-Z]*$/i;
+	return ();
+}
