@@ -6,7 +6,7 @@ use locale;
 use POSIX;
 use DBIx::dbMan::Config;
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 1;
 
@@ -16,6 +16,25 @@ sub new {
 	return $obj;
 }
 
+sub load_and_store {
+	my $obj = shift;
+
+	my $file = $obj->historyfile;
+
+	return () unless $file;
+	
+	my @lines = ();
+
+	if (open F,$file) {
+		while (<F>) {
+			chomp;
+			push @lines,$_;
+		}	
+		close F;
+	}
+	$obj->{buffer} = \@lines;
+}
+
 sub load {
 	my $obj = shift;
 
