@@ -6,7 +6,7 @@ use DBIx::dbMan::Interface;
 use DBIx::dbMan::History;
 use Term::Size;
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 @ISA = qw/DBIx::dbMan::Interface/;
 
 1;
@@ -26,6 +26,17 @@ sub init {
 		for ($obj->{history}->load()) {
 			$obj->{readline}->addhistory($_);
 		}
+		$readline'rl_completion_function = sub { 
+			my ($text,$line,$start) = @_;
+			my %action = (action => 'LINE_COMPLETE',
+				text => $text, line => $line, start => $start);
+			do {
+				%action = $obj->{-core}->handle_action(%action);
+			} until ($action{processed});
+			return @{$action{list}} if ref $action{list} eq 'ARRAY';
+			return $action{list} if $action{list};
+			return ();
+		};
 	}
 }
 
@@ -48,4 +59,3 @@ sub render_size {
 	my $obj = shift;
 	return Term::Size::chars(*STDOUT{IO})-1;
 }
-
